@@ -73,10 +73,15 @@ STRUCTURE = Nav(
 			lazy_gettext("Archétypes"),
 			index=True,
 			children=[
+				Nav(lazy_gettext("Adeliz, the Cinder Wind")),
+				Nav(lazy_gettext("Aminatou, the Fateshifter")),
 				Nav(lazy_gettext("Isamaru, Hound of Konda")),
+				Nav(lazy_gettext("Golos, Tireless Pilgrim")),
 				Nav(lazy_gettext("Kelsien, the Plague")),
 				Nav(lazy_gettext("Kess, Dissident Mage")),
 				Nav(lazy_gettext("Rowan and Will Kenrith")),
+				Nav(lazy_gettext("The Gitrog Monster")),
+				Nav(lazy_gettext("Titania, Protector of Argoth")),
 				Nav(lazy_gettext("Winota, Joiner of Forces")),
 			],
 		),
